@@ -180,6 +180,16 @@ TpProxySignalConnection *tp_cli_channel_interface_conference_connect_to_channel_
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_channel_interface_dtmf_signal_callback_tones_deferred) (TpChannel *proxy,
+    const gchar *arg_Tones,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_dtmf_connect_to_tones_deferred (TpChannel *proxy,
+    tp_cli_channel_interface_dtmf_signal_callback_tones_deferred callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_channel_interface_dtmf_signal_callback_sending_tones) (TpChannel *proxy,
     const gchar *arg_Tones,
     gpointer user_data, GObject *weak_object);
@@ -815,6 +825,145 @@ gboolean tp_cli_channel_interface_password_run_provide_password (TpChannel *prox
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_channel_interface_sasl_authentication_signal_callback_sasl_status_changed) (TpChannel *proxy,
+    guint arg_Status,
+    const gchar *arg_Reason,
+    GHashTable *arg_Details,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_sasl_authentication_connect_to_sasl_status_changed (TpChannel *proxy,
+    tp_cli_channel_interface_sasl_authentication_signal_callback_sasl_status_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_interface_sasl_authentication_signal_callback_new_challenge) (TpChannel *proxy,
+    const GArray *arg_Challenge_Data,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_sasl_authentication_connect_to_new_challenge (TpChannel *proxy,
+    tp_cli_channel_interface_sasl_authentication_signal_callback_new_challenge callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_interface_sasl_authentication_callback_for_start_mechanism) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_sasl_authentication_call_start_mechanism (TpChannel *proxy,
+    gint timeout_ms,
+    const gchar *in_Mechanism,
+    tp_cli_channel_interface_sasl_authentication_callback_for_start_mechanism callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_interface_sasl_authentication_run_start_mechanism (TpChannel *proxy,
+    gint timeout_ms,
+    const gchar *in_Mechanism,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_channel_interface_sasl_authentication_callback_for_start_mechanism_with_data) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_sasl_authentication_call_start_mechanism_with_data (TpChannel *proxy,
+    gint timeout_ms,
+    const gchar *in_Mechanism,
+    const GArray *in_Initial_Data,
+    tp_cli_channel_interface_sasl_authentication_callback_for_start_mechanism_with_data callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_interface_sasl_authentication_run_start_mechanism_with_data (TpChannel *proxy,
+    gint timeout_ms,
+    const gchar *in_Mechanism,
+    const GArray *in_Initial_Data,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_channel_interface_sasl_authentication_callback_for_respond) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_sasl_authentication_call_respond (TpChannel *proxy,
+    gint timeout_ms,
+    const GArray *in_Response_Data,
+    tp_cli_channel_interface_sasl_authentication_callback_for_respond callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_interface_sasl_authentication_run_respond (TpChannel *proxy,
+    gint timeout_ms,
+    const GArray *in_Response_Data,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_channel_interface_sasl_authentication_callback_for_accept_sasl) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_sasl_authentication_call_accept_sasl (TpChannel *proxy,
+    gint timeout_ms,
+    tp_cli_channel_interface_sasl_authentication_callback_for_accept_sasl callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_interface_sasl_authentication_run_accept_sasl (TpChannel *proxy,
+    gint timeout_ms,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_channel_interface_sasl_authentication_callback_for_abort_sasl) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_sasl_authentication_call_abort_sasl (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_Reason,
+    const gchar *in_Debug_Message,
+    tp_cli_channel_interface_sasl_authentication_callback_for_abort_sasl callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_interface_sasl_authentication_run_abort_sasl (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_Reason,
+    const gchar *in_Debug_Message,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_channel_interface_sms_signal_callback_sms_channel_changed) (TpChannel *proxy,
+    gboolean arg_SMSChannel,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_sms_connect_to_sms_channel_changed (TpChannel *proxy,
+    tp_cli_channel_interface_sms_signal_callback_sms_channel_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_channel_interface_service_point_signal_callback_service_point_changed) (TpChannel *proxy,
     const GValueArray *arg_Service_Point,
     gpointer user_data, GObject *weak_object);
@@ -1006,6 +1155,16 @@ TpProxySignalConnection *tp_cli_channel_type_file_transfer_connect_to_initial_of
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_channel_type_file_transfer_signal_callback_uri_defined) (TpChannel *proxy,
+    const gchar *arg_URI,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_file_transfer_connect_to_uri_defined (TpChannel *proxy,
+    tp_cli_channel_type_file_transfer_signal_callback_uri_defined callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_channel_type_file_transfer_callback_for_accept_file) (TpChannel *proxy,
     const GValue *out_Address,
     const GError *error, gpointer user_data,
