@@ -57,6 +57,46 @@ tp_svc_channel_dispatcher_return_from_ensure_channel (DBusGMethodInvocation *con
       out_Request);
 }
 
+typedef void (*tp_svc_channel_dispatcher_create_channel_with_hints_impl) (TpSvcChannelDispatcher *self,
+    const gchar *in_Account,
+    GHashTable *in_Requested_Properties,
+    gint64 in_User_Action_Time,
+    const gchar *in_Preferred_Handler,
+    GHashTable *in_Hints,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_dispatcher_implement_create_channel_with_hints (TpSvcChannelDispatcherClass *klass, tp_svc_channel_dispatcher_create_channel_with_hints_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_dispatcher_return_from_create_channel_with_hints (DBusGMethodInvocation *context,
+    const gchar *out_Request);
+static inline void
+tp_svc_channel_dispatcher_return_from_create_channel_with_hints (DBusGMethodInvocation *context,
+    const gchar *out_Request)
+{
+  dbus_g_method_return (context,
+      out_Request);
+}
+
+typedef void (*tp_svc_channel_dispatcher_ensure_channel_with_hints_impl) (TpSvcChannelDispatcher *self,
+    const gchar *in_Account,
+    GHashTable *in_Requested_Properties,
+    gint64 in_User_Action_Time,
+    const gchar *in_Preferred_Handler,
+    GHashTable *in_Hints,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_dispatcher_implement_ensure_channel_with_hints (TpSvcChannelDispatcherClass *klass, tp_svc_channel_dispatcher_ensure_channel_with_hints_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_dispatcher_return_from_ensure_channel_with_hints (DBusGMethodInvocation *context,
+    const gchar *out_Request);
+static inline void
+tp_svc_channel_dispatcher_return_from_ensure_channel_with_hints (DBusGMethodInvocation *context,
+    const gchar *out_Request)
+{
+  dbus_g_method_return (context,
+      out_Request);
+}
+
 
 typedef struct _TpSvcChannelDispatcherInterfaceOperationList TpSvcChannelDispatcherInterfaceOperationList;
 
