@@ -241,6 +241,8 @@ tp_svc_channel_interface_dtmf_return_from_multiple_tones (DBusGMethodInvocation
   dbus_g_method_return (context);
 }
 
+void tp_svc_channel_interface_dtmf_emit_tones_deferred (gpointer instance,
+    const gchar *arg_Tones);
 void tp_svc_channel_interface_dtmf_emit_sending_tones (gpointer instance,
     const gchar *arg_Tones);
 void tp_svc_channel_interface_dtmf_emit_stopped_tones (gpointer instance,
@@ -674,6 +676,94 @@ void tp_svc_channel_interface_password_emit_password_flags_changed (gpointer ins
     guint arg_Added,
     guint arg_Removed);
 
+typedef struct _TpSvcChannelInterfaceSASLAuthentication TpSvcChannelInterfaceSASLAuthentication;
+
+typedef struct _TpSvcChannelInterfaceSASLAuthenticationClass TpSvcChannelInterfaceSASLAuthenticationClass;
+
+GType tp_svc_channel_interface_sasl_authentication_get_type (void);
+#define TP_TYPE_SVC_CHANNEL_INTERFACE_SASL_AUTHENTICATION \
+  (tp_svc_channel_interface_sasl_authentication_get_type ())
+#define TP_SVC_CHANNEL_INTERFACE_SASL_AUTHENTICATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SASL_AUTHENTICATION, TpSvcChannelInterfaceSASLAuthentication))
+#define TP_IS_SVC_CHANNEL_INTERFACE_SASL_AUTHENTICATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SASL_AUTHENTICATION))
+#define TP_SVC_CHANNEL_INTERFACE_SASL_AUTHENTICATION_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SASL_AUTHENTICATION, TpSvcChannelInterfaceSASLAuthenticationClass))
+
+
+typedef void (*tp_svc_channel_interface_sasl_authentication_start_mechanism_impl) (TpSvcChannelInterfaceSASLAuthentication *self,
+    const gchar *in_Mechanism,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_sasl_authentication_implement_start_mechanism (TpSvcChannelInterfaceSASLAuthenticationClass *klass, tp_svc_channel_interface_sasl_authentication_start_mechanism_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_sasl_authentication_return_from_start_mechanism (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_interface_sasl_authentication_return_from_start_mechanism (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_channel_interface_sasl_authentication_start_mechanism_with_data_impl) (TpSvcChannelInterfaceSASLAuthentication *self,
+    const gchar *in_Mechanism,
+    const GArray *in_Initial_Data,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_sasl_authentication_implement_start_mechanism_with_data (TpSvcChannelInterfaceSASLAuthenticationClass *klass, tp_svc_channel_interface_sasl_authentication_start_mechanism_with_data_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_sasl_authentication_return_from_start_mechanism_with_data (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_interface_sasl_authentication_return_from_start_mechanism_with_data (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_channel_interface_sasl_authentication_respond_impl) (TpSvcChannelInterfaceSASLAuthentication *self,
+    const GArray *in_Response_Data,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_sasl_authentication_implement_respond (TpSvcChannelInterfaceSASLAuthenticationClass *klass, tp_svc_channel_interface_sasl_authentication_respond_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_sasl_authentication_return_from_respond (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_interface_sasl_authentication_return_from_respond (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_channel_interface_sasl_authentication_accept_sasl_impl) (TpSvcChannelInterfaceSASLAuthentication *self,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_sasl_authentication_implement_accept_sasl (TpSvcChannelInterfaceSASLAuthenticationClass *klass, tp_svc_channel_interface_sasl_authentication_accept_sasl_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_sasl_authentication_return_from_accept_sasl (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_interface_sasl_authentication_return_from_accept_sasl (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_channel_interface_sasl_authentication_abort_sasl_impl) (TpSvcChannelInterfaceSASLAuthentication *self,
+    guint in_Reason,
+    const gchar *in_Debug_Message,
+    DBusGMethodInvocation *context);
+void tp_svc_channel_interface_sasl_authentication_implement_abort_sasl (TpSvcChannelInterfaceSASLAuthenticationClass *klass, tp_svc_channel_interface_sasl_authentication_abort_sasl_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_channel_interface_sasl_authentication_return_from_abort_sasl (DBusGMethodInvocation *context);
+static inline void
+tp_svc_channel_interface_sasl_authentication_return_from_abort_sasl (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+void tp_svc_channel_interface_sasl_authentication_emit_sasl_status_changed (gpointer instance,
+    guint arg_Status,
+    const gchar *arg_Reason,
+    GHashTable *arg_Details);
+void tp_svc_channel_interface_sasl_authentication_emit_new_challenge (gpointer instance,
+    const GArray *arg_Challenge_Data);
+
 typedef struct _TpSvcChannelInterfaceSMS TpSvcChannelInterfaceSMS;
 
 typedef struct _TpSvcChannelInterfaceSMSClass TpSvcChannelInterfaceSMSClass;
@@ -689,6 +779,24 @@ GType tp_svc_channel_interface_sms_get_type (void);
   (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SMS, TpSvcChannelInterfaceSMSClass))
 
 
+void tp_svc_channel_interface_sms_emit_sms_channel_changed (gpointer instance,
+    gboolean arg_SMSChannel);
+
+typedef struct _TpSvcChannelInterfaceSecurable TpSvcChannelInterfaceSecurable;
+
+typedef struct _TpSvcChannelInterfaceSecurableClass TpSvcChannelInterfaceSecurableClass;
+
+GType tp_svc_channel_interface_securable_get_type (void);
+#define TP_TYPE_SVC_CHANNEL_INTERFACE_SECURABLE \
+  (tp_svc_channel_interface_securable_get_type ())
+#define TP_SVC_CHANNEL_INTERFACE_SECURABLE(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SECURABLE, TpSvcChannelInterfaceSecurable))
+#define TP_IS_SVC_CHANNEL_INTERFACE_SECURABLE(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SECURABLE))
+#define TP_SVC_CHANNEL_INTERFACE_SECURABLE_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_INTERFACE_SECURABLE, TpSvcChannelInterfaceSecurableClass))
+
+
 
 typedef struct _TpSvcChannelInterfaceServicePoint TpSvcChannelInterfaceServicePoint;
 
@@ -912,6 +1020,8 @@ void tp_svc_channel_type_file_transfer_emit_transferred_bytes_changed (gpointer
     guint64 arg_Count);
 void tp_svc_channel_type_file_transfer_emit_initial_offset_defined (gpointer instance,
     guint64 arg_InitialOffset);
+void tp_svc_channel_type_file_transfer_emit_uri_defined (gpointer instance,
+    const gchar *arg_URI);
 
 typedef struct _TpSvcChannelTypeRoomList TpSvcChannelTypeRoomList;
 
@@ -972,6 +1082,22 @@ void tp_svc_channel_type_room_list_emit_got_rooms (gpointer instance,
 void tp_svc_channel_type_room_list_emit_listing_rooms (gpointer instance,
     gboolean arg_Listing);
 
+typedef struct _TpSvcChannelTypeServerAuthentication TpSvcChannelTypeServerAuthentication;
+
+typedef struct _TpSvcChannelTypeServerAuthenticationClass TpSvcChannelTypeServerAuthenticationClass;
+
+GType tp_svc_channel_type_server_authentication_get_type (void);
+#define TP_TYPE_SVC_CHANNEL_TYPE_SERVER_AUTHENTICATION \
+  (tp_svc_channel_type_server_authentication_get_type ())
+#define TP_SVC_CHANNEL_TYPE_SERVER_AUTHENTICATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CHANNEL_TYPE_SERVER_AUTHENTICATION, TpSvcChannelTypeServerAuthentication))
+#define TP_IS_SVC_CHANNEL_TYPE_SERVER_AUTHENTICATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CHANNEL_TYPE_SERVER_AUTHENTICATION))
+#define TP_SVC_CHANNEL_TYPE_SERVER_AUTHENTICATION_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CHANNEL_TYPE_SERVER_AUTHENTICATION, TpSvcChannelTypeServerAuthenticationClass))
+
+
+
 typedef struct _TpSvcChannelTypeServerTLSConnection TpSvcChannelTypeServerTLSConnection;
 
 typedef struct _TpSvcChannelTypeServerTLSConnectionClass TpSvcChannelTypeServerTLSConnectionClass;
