@@ -90,27 +90,6 @@ typedef gboolean (*TpGroupMixinRemMemberWithReasonFunc) (GObject *obj,
 void tp_group_mixin_class_set_remove_with_reason_func (GObjectClass *cls,
     TpGroupMixinRemMemberWithReasonFunc func);
 
-/**
- * TpGroupMixinClass:
- * @add_member: The add-member function that was passed to
- *  tp_group_mixin_class_init()
- * @remove_member: The remove-member function that was passed to
- *  tp_group_mixin_class_init()
- * @priv: Pointer to opaque private data
- *
- * Structure representing the group mixin as used in a particular class.
- * To be placed in the implementation's class structure.
- *
- * Initialize this with tp_group_mixin_class_init().
- *
- * All fields should be considered read-only.
- */
-struct _TpGroupMixinClass {
-  TpGroupMixinAddMemberFunc add_member;
-  TpGroupMixinRemMemberFunc remove_member;
-  TpGroupMixinClassPrivate *priv;
-};
-
 /**
  * TpGroupMixin:
  * @handle_repo: The connection's contact handle repository
@@ -144,6 +123,27 @@ struct _TpGroupMixin {
   TpGroupMixinPrivate *priv;
 };
 
+/**
+ * TpGroupMixinClass:
+ * @add_member: The add-member function that was passed to
+ *  tp_group_mixin_class_init()
+ * @remove_member: The remove-member function that was passed to
+ *  tp_group_mixin_class_init()
+ * @priv: Pointer to opaque private data
+ *
+ * Structure representing the group mixin as used in a particular class.
+ * To be placed in the implementation's class structure.
+ *
+ * Initialize this with tp_group_mixin_class_init().
+ *
+ * All fields should be considered read-only.
+ */
+struct _TpGroupMixinClass {
+  TpGroupMixinAddMemberFunc add_member;
+  TpGroupMixinRemMemberFunc remove_member;
+  TpGroupMixinClassPrivate *priv;
+};
+
 /* TYPE MACROS */
 #define TP_GROUP_MIXIN_CLASS_OFFSET_QUARK \
   (tp_group_mixin_class_get_offset_quark ())
@@ -152,12 +152,14 @@ struct _TpGroupMixin {
 #define TP_GROUP_MIXIN_CLASS(o) \
   ((TpGroupMixinClass *) tp_mixin_offset_cast (o, \
     TP_GROUP_MIXIN_CLASS_OFFSET (o)))
+#define TP_HAS_GROUP_MIXIN_CLASS(cls) (TP_GROUP_MIXIN_CLASS_OFFSET (cls) != 0)
 
 #define TP_GROUP_MIXIN_OFFSET_QUARK (tp_group_mixin_get_offset_quark ())
 #define TP_GROUP_MIXIN_OFFSET(o) \
   tp_mixin_instance_get_offset (o, TP_GROUP_MIXIN_OFFSET_QUARK)
 #define TP_GROUP_MIXIN(o) ((TpGroupMixin *) tp_mixin_offset_cast (o, \
       TP_GROUP_MIXIN_OFFSET(o)))
+#define TP_HAS_GROUP_MIXIN(o) (TP_GROUP_MIXIN_OFFSET (o) != 0)
 
 GQuark tp_group_mixin_class_get_offset_quark (void);
 GQuark tp_group_mixin_get_offset_quark (void);
