@@ -32,6 +32,7 @@
 G_BEGIN_DECLS
 
 gboolean tp_g_ptr_array_contains (GPtrArray *haystack, gpointer needle);
+void tp_g_ptr_array_extend (GPtrArray *target, GPtrArray *source);
 
 GValue *tp_g_value_slice_new (GType type) G_GNUC_WARN_UNUSED_RESULT;
 
@@ -64,10 +65,8 @@ GValue *tp_g_value_slice_dup (const GValue *value) G_GNUC_WARN_UNUSED_RESULT;
 void tp_g_hash_table_update (GHashTable *target, GHashTable *source,
     GBoxedCopyFunc key_dup, GBoxedCopyFunc value_dup);
 
-#define tp_str_empty(s) (tp_str_empty_inline (s))
-
 static inline gboolean
-tp_str_empty_inline (const gchar *s)
+tp_str_empty (const gchar *s)
 {
   return (s == NULL || s[0] == '\0');
 }
@@ -109,15 +108,13 @@ void tp_weak_ref_destroy (TpWeakRef *self);
 #define tp_clear_pointer(pp, destroy) \
   G_STMT_START \
     { \
-      if (pp != NULL) \
-        { \
-          gpointer _tp_clear_pointer_tmp = *(pp); \
-          \
-          *(pp) = NULL; \
-          \
-          if (_tp_clear_pointer_tmp != NULL) \
-            (destroy) (_tp_clear_pointer_tmp); \
-        } \
+      gpointer _tp_clear_pointer_tmp; \
+      \
+      _tp_clear_pointer_tmp = *(pp); \
+      *(pp) = NULL; \
+      \
+      if (_tp_clear_pointer_tmp != NULL) \
+        (destroy) (_tp_clear_pointer_tmp); \
     } \
   G_STMT_END
 
@@ -126,15 +123,13 @@ void tp_weak_ref_destroy (TpWeakRef *self);
 #define tp_clear_boxed(gtype, pp) \
   G_STMT_START \
     { \
-      if (pp != NULL) \
-        { \
-          gpointer _tp_clear_boxed_tmp = *(pp); \
-          \
-          *(pp) = NULL; \
-          \
-          if (_tp_clear_boxed_tmp != NULL) \
-            g_boxed_free (gtype, _tp_clear_boxed_tmp); \
-        } \
+      gpointer _tp_clear_boxed_tmp; \
+      \
+      _tp_clear_boxed_tmp = *(pp); \
+      *(pp) = NULL; \
+      \
+      if (_tp_clear_boxed_tmp != NULL) \
+        g_boxed_free (gtype, _tp_clear_boxed_tmp); \
     } \
   G_STMT_END
 
@@ -145,6 +140,8 @@ gint64 tp_user_action_time_from_x11 (guint32 x11_time);
 gboolean tp_user_action_time_should_present (gint64 user_action_time,
     guint32 *x11_time);
 
+gchar *tp_utf8_make_valid (const gchar *name);
+
 G_END_DECLS
 
 #undef  __TP_IN_UTIL_H__
